==> cylc_6.11.2.orig.tar.xz: cylc-6.11.2/README.md <==
# The Cylc Suite Engine

[![Build Status](https://travis-ci.org/cylc/cylc.svg?branch=master)](https://travis-ci.org/cylc/cylc)

## A Workflow Engine and Meta-Scheduler

Cylc specialises in continuous workflows of cycling (repeating) tasks such as
those used in weather and climate forecasting and research, but it can also be
used for non-cycling systems.

### Copyright and Terms of Use

Copyright (C) 2008-2016 [NIWA](https://www.niwa.co.nz)
 
Cylc is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.
 
Cylc is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License along with
cylc.  If not, see [GNU licenses](http://www.gnu.org/licenses/).

## Cylc Documentation
 * See [The Cylc Home Page](https://cylc.github.io/cylc)

## Code Contributors
<!--  git shortlog -s -n -->
 *  Hilary Oliver
 *  Ben Fitzpatrick
 *  Matt Shin
 *  Andrew Clark
 *  Luis Kornblueh
 *  Kerry Day
 *  David Matthews
 *  Scott Wales
 *  Tim Whitcomb
 *  Oliver Sanders
 *  Annette Osprey
 *  Domingo Manubens Gil
 *  Alex Reinecke
 *  Bruno Kinoshita
 *  Chandin Wilson
 *  Kevin Pulo
 
## Acknowledgement For Non-Cylc Work:
Licences for non-cylc work included in this distribution can be found in the
`licences/` directory.
 * `lib/isodatetime/`:
    Unmodified external software library released under the LGPL license.
    See [metomi/isodatetime](https://github.com/metomi/isodatetime).
 * `lib/Pyro/`:
    External software library released under the MIT license.
    Minor modification based on version 3.16.
    See [Pyro 3.16](https://pypi.python.org/pypi/Pyro).
 * `lib/xdot.py`:
    External software released under the LGPL license.
    Modifications based on version 0.6. See
    [xdot](https://github.com/jrfonseca/xdot.py)

==> cylc_7.6.0.orig.tar.xz: cylc-7.6.0/README.md <==
# The Cylc Workflow Engine

[![Build Status](https://travis-ci.org/cylc/cylc.svg?branch=master)](https://travis-ci.org/cylc/cylc)
[![DOI](https://zenodo.org/badge/1836229.svg)](https://zenodo.org/badge/latestdoi/1836229)

Cylc (“silk”) orchestrates complex distributed suites of interdependent cycling
tasks. It was originally designed for environmental forecasting systems at
[NIWA](https://www.niwa.co.nz).

### Copyright and Terms of Use

Copyright (C) 2008-2017 NIWA
 
Cylc is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.
 
Cylc is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License along with
cylc.  If not, see [GNU licenses](http://www.gnu.org/licenses/).

## Cylc Documentation
 * See [The Cylc Home Page](https://cylc.github.io/cylc)

## Code Contributors
<!--  git shortlog -s -n -->
 *  Hilary Oliver
 *  Matt Shin
 *  Ben Fitzpatrick
 *  Andrew Clark
 *  Oliver Sanders
 *  Luis Kornblueh
 *  Kerry Day
 *  David Matthews
 *  Tim Whitcomb
 *  Scott Wales
 *  Annette Osprey
 *  Bruno Kinoshita
 *  Domingo Manubens Gil
 *  Jonny Williams
 *  Alex Reinecke
 *  Chan Wilson
 *  Kevin Pulo
 
## Acknowledgement For Non-Cylc Work:
Licences for non-cylc work included in this distribution can be found in the
`licences/` directory.
 * `lib/cherrypy/`:
    External software library released under a BSD license.
    Minor modification to ignore an import warning.
    See [cherrypy](http://www.cherrypy.org/).
 * `lib/isodatetime/`:
    Unmodified external software library released under the LGPL license.
    See [metomi/isodatetime](https://github.com/metomi/isodatetime/).
 * `lib/jinja2/`:
    External software library released under a BSD license.
    See [Jinja2](http://jinja.pocoo.org/).
 * `lib/markupsafe/`:
    External software library released under a BSD license, used by Jinja2.
    See [MarkupSafe](http://www.pocoo.org/projects/markupsafe/).
 * `lib/xdot.py`:
    External software released under the LGPL license.
    Modifications based on version 0.6. See
    [xdot](https://github.com/jrfonseca/xdot.py)
